@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2009 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ void set_nut_table(void);
 void label_nut_list(int);
 void get_nut_value(float *);
 void guess_recipe();
-void solve_it(int, int *, int *);
+void solve_it(int, int *, int *, int *);
 void modify_servings(void);
 
 #endif
