@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2008 by Jim Jozwiak.
+    Copyright (C) 1996-2009 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -173,10 +173,39 @@ return meal_ptr;
 
 void modify_meal(char *meal_date, int meal, int num, char *qty)
 {
-struct meal *m, *meal_ptr = &meal_root;
-int count = 0;
-float newqty;
-while (meal_ptr->next != NULL)
+struct meal *m = NULL, *meal_ptr = &meal_root;
+int count = 0, nut = -1;
+float newqty, total = 0, thiscontrib = 0;
+if (qty != NULL && strcmp(qty,"protein") == 0) nut = PROCNT;
+if (qty != NULL && strcmp(qty,"prot") == 0) nut = PROCNT;
+if (qty != NULL && strcmp(qty,"pro") == 0) nut = PROCNT;
+else if (qty != NULL && strcmp(qty,"carb") == 0) nut = CHO_NONFIB;
+else if (qty != NULL && strcmp(qty,"car") == 0) nut = CHO_NONFIB;
+else if (qty != NULL && strcmp(qty,"fat") == 0) nut = FAT;
+if (nut != -1) while (meal_ptr->next != NULL)
+ {
+ if (strcmp(meal_date,meal_ptr->next->meal_date) == 0 && meal == meal_ptr->next->meal) 
+  {
+  count++;
+  if (count == num) m = meal_ptr;
+  total += options.mealsperday * meal_ptr->next->grams / 100 * FoodIndex[meal_ptr->next->food_no]->nutrient[nut];
+  }
+ meal_ptr = meal_ptr->next;
+ }
+if (nut != -1 && m != NULL)
+ {
+ thiscontrib = options.mealsperday * m->next->grams / 100 * FoodIndex[m->next->food_no]->nutrient[nut];
+ newqty = (thiscontrib + DV[nut] - total) / thiscontrib * m->next->grams;
+ if (newqty <= 0)
+  {
+  meal_ptr = m->next;
+  m->next = m->next->next;
+  free(meal_ptr);
+  }
+ else if (FoodIndex[m->next->food_no]->nutrient[nut] > 0) m->next->grams = newqty;
+ return;
+ }
+if (nut == -1) while (meal_ptr->next != NULL)
  {
  if (strcmp(meal_date,meal_ptr->next->meal_date) == 0 && meal == meal_ptr->next->meal) 
   {
@@ -230,10 +259,39 @@ while (meal_ptr->next != NULL)
 
 void modify_theusual(char *meal_date, int num, char *qty)
 {
-struct meal *m, *theusual_ptr = &theusual_root;
-int count = 0;
-float newqty;
-while (theusual_ptr->next != NULL)
+struct meal *m = NULL, *theusual_ptr = &theusual_root;
+int count = 0, nut = -1;
+float newqty, total = 0, thiscontrib = 0;
+if (qty != NULL && strcmp(qty,"protein") == 0) nut = PROCNT;
+if (qty != NULL && strcmp(qty,"prot") == 0) nut = PROCNT;
+if (qty != NULL && strcmp(qty,"pro") == 0) nut = PROCNT;
+else if (qty != NULL && strcmp(qty,"carb") == 0) nut = CHO_NONFIB;
+else if (qty != NULL && strcmp(qty,"car") == 0) nut = CHO_NONFIB;
+else if (qty != NULL && strcmp(qty,"fat") == 0) nut = FAT;
+if (nut != -1) while (theusual_ptr->next != NULL)
+ {
+ if (strcmp(meal_date,theusual_ptr->next->meal_date) == 0) 
+  {
+  count++;
+  if (count == num) m = theusual_ptr;
+  total += options.mealsperday * theusual_ptr->next->grams / 100 * FoodIndex[theusual_ptr->next->food_no]->nutrient[nut];
+  }
+ theusual_ptr = theusual_ptr->next;
+ }
+if (nut != -1 && m != NULL)
+ {
+ thiscontrib = options.mealsperday * m->next->grams / 100 * FoodIndex[m->next->food_no]->nutrient[nut];
+ newqty = (thiscontrib + DV[nut] - total) / thiscontrib * m->next->grams;
+ if (newqty <= 0)
+  {
+  theusual_ptr = m->next;
+  m->next = m->next->next;
+  free(theusual_ptr);
+  }
+ else if (FoodIndex[m->next->food_no]->nutrient[nut] > 0) m->next->grams = newqty;
+ return;
+ }
+if (nut == -1) while (theusual_ptr->next != NULL)
  {
  if (strcmp(meal_date,theusual_ptr->next->meal_date) == 0) 
   {
