@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2008 by Jim Jozwiak.
+    Copyright (C) 1996-2009 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 
 struct opt options;
 
-static float DefaultTarget = 75, DefaultEPADHA = 1.2;
+static float DefaultTarget = 90, DefaultEPADHA = 0.7;
 
 void initialize_options()
 {
@@ -151,7 +151,7 @@ while (1)
   if (options.locknuts[FAPU] != 1) printf("           3.  Change EPA+DHA maximum grams (currently %3.1f grams).\n\n",options.epadhamax == 0 ? DefaultEPADHA : options.epadhamax);
   if (options.locknuts[FAPU] != 1) spacer(8);
   else spacer(4);
-  printf("\nEnter new Omega-6 percentage (15-90):  ");
+  printf("\nEnter new Omega-6 percentage (15-90, 90 = off):  ");
   get_string(buf,127);
   tempfloat = atof(buf);
   if (tempfloat < 15 || tempfloat > 90) break;
@@ -594,31 +594,52 @@ void efa_dynamics()
 {
 int i;
 float temp, temp1, temp_la = 0, temp_aa = 0, hufapct, p3, h3, h6, p6, o;
-float target = DefaultTarget, epadhalimit, extra_ala;
+float kludgefactor = .9;
+float target = DefaultTarget + kludgefactor, epadhalimit, extra_ala;
 
 if (options.n6hufa != 0)
  {
  if (options.n6hufa < 15) options.n6hufa = 15;
  if (options.n6hufa > 90) options.n6hufa = 90;
  }
-
+  
 if (options.epadhamax <= 0) epadhalimit = DefaultEPADHA;
 else epadhalimit = options.epadhamax;
-if (options.n6hufa != 0) target = options.n6hufa;
-  
-  
-DV[ALA] = food_work.nutrient[ALA];
-if (DV[ALA] <= 0) DV[ALA] = .00001;
 
-  
-/*  
-if (food_work.nutrient[ALA] > DV[ALA]) DV[ALA] = food_work.nutrient[ALA];
-*/  
+options.abnuts[ALA] = food_work.nutrient[ALA];
+if (options.abnuts[ALA] < DV[ALA]) options.abnuts[ALA] = DV[ALA];
+extra_ala = options.abnuts[ALA] - food_work.nutrient[ALA];
+
+if ( (DefaultTarget == 90 && options.n6hufa == 0) || options.n6hufa == 90 || options.n6hufa == 15)
+ {
+ options.abnuts[OMEGA6] = food_work.nutrient[OMEGA6];
+ if (options.abnuts[OMEGA6] <= 0) options.abnuts[OMEGA6] = .00001;
+ options.abnuts[LA] = food_work.nutrient[LA];
+ if (options.abnuts[LA] <= 0) options.abnuts[LA] = .00001;
+ options.abnuts[AA] = food_work.nutrient[AA];
+ if (options.abnuts[AA] <= 0) options.abnuts[AA] = .00001;
+ options.abnuts[OMEGA3] = food_work.nutrient[OMEGA3] + extra_ala;
+ if (options.abnuts[OMEGA3] <= 0) options.abnuts[OMEGA3] = .00001;
+ options.abnuts[EPA] = food_work.nutrient[EPA];
+ if (options.abnuts[EPA] <= 0) options.abnuts[EPA] = .00001;
+ options.abnuts[DHA] = food_work.nutrient[DHA];
+ if (options.abnuts[DHA] <= 0) options.abnuts[DHA] = .00001;
+ if (options.abnuts[EPA] + options.abnuts[DHA] < DefaultEPADHA && (food_work.nutrient[EPA] > .01 || food_work.nutrient[DHA] > .01 || food_work.nutrient[AA] > .01))
+  {
+  temp1 = epadhalimit - (options.abnuts[EPA] + options.abnuts[DHA]);
+  temp = epadhalimit / (options.abnuts[EPA] + options.abnuts[DHA]);
+  options.abnuts[EPA] *= temp;
+  options.abnuts[DHA] *= temp;
+  options.abnuts[OMEGA3] += temp1;
+  }
+ return;
+ }
+
+if (options.n6hufa != 0) target = options.n6hufa + kludgefactor;
 
 options.abnuts[AA] = food_work.nutrient[AA];
 options.abnuts[LA] = food_work.nutrient[LA];
-options.abnuts[ALA] = DV[ALA];
-extra_ala = DV[ALA] - food_work.nutrient[ALA];
+extra_ala = options.abnuts[ALA] - food_work.nutrient[ALA];
 p3 = 902 * (food_work.nutrient[SHORT3] + extra_ala) / food_work.nutrient[ENERC_KCAL];
 p6 = 902 * food_work.nutrient[SHORT6] / food_work.nutrient[ENERC_KCAL];
 h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
