@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2008 by Jim Jozwiak.
+    Copyright (C) 1996-2009 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -196,7 +196,9 @@ if (opt == 5)
   food_ptr = food_ptr->next;
   if (mincount == 0 ||
       test_for_negative_zero(&food_ptr->nutrient[num]) ||
+/*
       test_for_negative_zero(&food_ptr->nutrient[Minut]) ||
+*/
       Minut == num ||
       (num == VITE && Minut == TOCPHA) || (num == TOCPHA && Minut == VITE) ||
       (num == LA && Minut == F18D2) || (num == F18D2 && Minut == LA) ||
@@ -311,7 +313,8 @@ while (displayed <= (FoodCount - 20) && (junk == 'm' || junk == 'M'))
   if (opt == 0 && options.screen > 0 && options.screen < 4 && !options.grams) printf("%-54s %6.1f oz %9.1f %-3s\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL] / GRAMS_IN_OUNCE,abacus[max],Unit[num]);
   if (opt == 0 && options.screen > 0 && options.screen > 3 && options.grams) printf("%-54s %7.1f g %9.2f %-3s\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL],abacus[max],Unit[num]);
   if (opt == 0 && options.screen > 0 && options.screen > 3 && !options.grams) printf("%-54s %6.1f oz %9.2f %-3s\n",thisname,10000 / food_ptr->nutrient[ENERC_KCAL] / GRAMS_IN_OUNCE,abacus[max],Unit[num]);
-  if (opt == 5) printf("%-52s %7.1f %-3s    %7.1f %-3s\n",thisname,food_ptr->grams / 100 * food_ptr->nutrient[num],Unit[num],food_ptr->grams / 100 * food_ptr->nutrient[Minut],Unit[Minut]);
+  if (opt == 5 && !test_for_negative_zero(&food_ptr->nutrient[Minut])) printf("%-52s %7.1f %-3s    %7.1f %-3s\n",thisname,food_ptr->grams / 100 * food_ptr->nutrient[num],Unit[num],food_ptr->grams / 100 * food_ptr->nutrient[Minut],Unit[Minut]);
+  if (opt == 5 && test_for_negative_zero(&food_ptr->nutrient[Minut])) printf("%-52s %7.1f %-3s        (nd)\n",thisname,food_ptr->grams / 100 * food_ptr->nutrient[num],Unit[num]);
   if (opt == 4 && options.screen == 0 && options.grams) printf("%-54s        %7.1f g %5.0f%%\n",thisname,food_ptr->grams,abacus[max]);
   if (opt == 4 && options.screen == 0 && !options.grams) printf("%-54s        %6.1f oz %5.0f%%\n",thisname,food_ptr->grams / GRAMS_IN_OUNCE,abacus[max]);
   if (opt == 4 && options.screen > 0 && options.screen < 4 && options.grams) printf("%-54s %7.1f g %9.1f %-3s\n",thisname,food_ptr->grams,abacus[max],Unit[num]);
